@@ -16,7 +16,8 @@ from .utils import (
     create_config_py,
     create_app_py,
     write_requirements,
-    create_gitignore
+    create_gitignore,
+    create_env
 )
 from ..__main__ import main
 
@@ -80,6 +81,11 @@ def startproject_command():
     processes.append(f"Created {hl('config.py')}")
     process_ok(processes)
 
+    # Creating .env
+    process_step(f"Creating {hl('.env')}...", create_env)
+    processes.append(f"Created {hl('.env')}")
+    process_ok(processes)
+
     # Creating project __init__.py
     process_step(f"Creating {hl(join(prj_name,'__init__.py'))}...",
                 create_init_py(prj_name))
